@@ -14,10 +14,12 @@
 #include "settings.h"
 #include "version.h"
 
+using namespace Qt::Literals::StringLiterals;
+
 QCommandLineParser *createParser()
 {
     QCommandLineParser *parser = new QCommandLineParser;
-    parser->addOption(QCommandLineOption(QStringLiteral("apply-settings"), "Applies the correct system settings for the current environment."));
+    parser->addOption(QCommandLineOption(u"apply-settings"_s, u"Applies the correct system settings for the current environment."_s));
     parser->addVersionOption();
     parser->addHelpOption();
     return parser;
@@ -33,13 +35,13 @@ int main(int argc, char *argv[])
 
     // start wizard
     KLocalizedString::setApplicationDomain("plasma-mobile-envmanager");
-    QCoreApplication::setApplicationName(QStringLiteral("plasma-mobile-envmanager"));
+    QCoreApplication::setApplicationName(u"plasma-mobile-envmanager"_s);
     QCoreApplication::setApplicationVersion(QStringLiteral(PLASMA_MOBILE_VERSION_STRING));
-    QCoreApplication::setOrganizationDomain(QStringLiteral("kde.org"));
+    QCoreApplication::setOrganizationDomain(u"kde.org"_s);
 
     // apply configuration
-    if (parser->isSet(QStringLiteral("apply-settings"))) {
-        Settings::self()->applyConfiguration();
+    if (parser->isSet(u"apply-settings"_s)) {
+        Settings::self().applyConfiguration();
     } else {
         parser->showHelp();
     }
