@@ -19,6 +19,10 @@ PrepareUtil::PrepareUtil(QObject *parent)
     connect(new KScreen::GetConfigOperation(), &KScreen::GetConfigOperation::finished, this, [this](auto *op) {
         m_config = qobject_cast<KScreen::GetConfigOperation *>(op)->config();
 
+        if (!m_config) {
+            return;
+        }
+
         int scaling = 100;
 
         // to determine the scaling value:
